#
# PySNMP MIB module DNS-RESOLVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DNS-RESOLVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:08:40 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( DnsNameAsIndex, DnsTime, dns, DnsType, DnsOpCode, DnsClass, DnsName, ) = mibBuilder.importSymbols("DNS-SERVER-MIB", "DnsNameAsIndex", "DnsTime", "dns", "DnsType", "DnsOpCode", "DnsClass", "DnsName")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( iso, IpAddress, Counter32, ObjectIdentity, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, NotificationType, Unsigned32, Integer32, Gauge32, ModuleIdentity, TimeTicks, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "IpAddress", "Counter32", "ObjectIdentity", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "NotificationType", "Unsigned32", "Integer32", "Gauge32", "ModuleIdentity", "TimeTicks", "MibIdentifier")
( TextualConvention, RowStatus, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "RowStatus", "DisplayString")
dnsResMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 32, 2))
if mibBuilder.loadTexts: dnsResMIB.setLastUpdated('9401282250Z')
if mibBuilder.loadTexts: dnsResMIB.setOrganization('IETF DNS Working Group')
if mibBuilder.loadTexts: dnsResMIB.setContactInfo('       Rob Austein\n               Postal: Epilogue Technology Corporation\n                       268 Main Street, Suite 283\n                       North Reading, MA 10864\n                       US\n                  Tel: +1 617 245 0804\n                  Fax: +1 617 245 8122\n               E-Mail: sra@epilogue.com\n\n                       Jon Saperia\n               Postal: Digital Equipment Corporation\n                       110 Spit Brook Road\n                       ZKO1-3/H18\n                       Nashua, NH 03062-2698\n                       US\n                  Tel: +1 603 881 0480\n                  Fax: +1 603 881 0120\n               E-mail: saperia@zko.dec.com')
if mibBuilder.loadTexts: dnsResMIB.setDescription('The MIB module for entities implementing the client\n               (resolver) side of the Domain Name System (DNS)\n               protocol.')
dnsResMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1))
dnsResConfig = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1, 1))
dnsResCounter = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1, 2))
dnsResLameDelegation = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1, 3))
dnsResCache = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1, 4))
dnsResNCache = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1, 5))
dnsResOptCounter = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 1, 6))
class DnsQClass(Integer32, TextualConvention):
    displayHint = '2d'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class DnsQType(Integer32, TextualConvention):
    displayHint = '2d'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class DnsRespCode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,15)

dnsResConfigImplementIdent = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 1), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResConfigImplementIdent.setDescription("The implementation identification string for the\n               resolver software in use on the system, for example;\n               `RES-2.1'")
dnsResConfigService = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("recursiveOnly", 1), ("iterativeOnly", 2), ("recursiveAndIterative", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResConfigService.setDescription('Kind of DNS resolution service provided:\n\n               recursiveOnly(1) indicates a stub resolver.\n\n               iterativeOnly(2) indicates a normal full service\n               resolver.\n\n               recursiveAndIterative(3) indicates a full-service\n               resolver which performs a mix of recursive and iterative\n               queries.')
dnsResConfigMaxCnames = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResConfigMaxCnames.setDescription("Limit on how many CNAMEs the resolver should allow\n               before deciding that there's a CNAME loop.  Zero means\n               that resolver has no explicit CNAME limit.")
dnsResConfigSbeltTable = MibTable((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4), )
if mibBuilder.loadTexts: dnsResConfigSbeltTable.setDescription("Table of safety belt information used by the resolver\n               when it hasn't got any better idea of where to send a\n               query, such as when the resolver is booting or is a stub\n               resolver.")
dnsResConfigSbeltEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1), ).setIndexNames((0, "DNS-RESOLVER-MIB", "dnsResConfigSbeltAddr"), (0, "DNS-RESOLVER-MIB", "dnsResConfigSbeltSubTree"), (0, "DNS-RESOLVER-MIB", "dnsResConfigSbeltClass"))
if mibBuilder.loadTexts: dnsResConfigSbeltEntry.setDescription("An entry in the resolver's Sbelt table.\n               Rows may be created or deleted at any time by the DNS\n               resolver and by SNMP SET requests.  Whether the values\n               changed via SNMP are saved in stable storage across\n               `reset' operations is implementation-specific.")
dnsResConfigSbeltAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 1), IpAddress())
if mibBuilder.loadTexts: dnsResConfigSbeltAddr.setDescription('The IP address of the Sbelt name server identified by\n               this row of the table.')
dnsResConfigSbeltName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 2), DnsName()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dnsResConfigSbeltName.setDescription('The DNS name of a Sbelt nameserver identified by this\n               row of the table.  A zero-length string indicates that\n               the name is not known by the resolver.')
dnsResConfigSbeltRecursion = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("iterative", 1), ("recursive", 2), ("recursiveAndIterative", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dnsResConfigSbeltRecursion.setDescription('Kind of queries resolver will be sending to the name\n               server identified in this row of the table:\n\n               iterative(1) indicates that resolver will be directing\n               iterative queries to this name server (RD bit turned\n               off).\n\n               recursive(2) indicates that resolver will be directing\n               recursive queries to this name server (RD bit turned\n               on).\n\n               recursiveAndIterative(3) indicates that the resolver\n               will be directing both recursive and iterative queries\n               to the server identified in this row of the table.')
dnsResConfigSbeltPref = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dnsResConfigSbeltPref.setDescription('This value identifies the preference for the name server\n               identified in this row of the table.  The lower the\n               value, the more desirable the resolver considers this\n               server.')
dnsResConfigSbeltSubTree = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 5), DnsNameAsIndex())
if mibBuilder.loadTexts: dnsResConfigSbeltSubTree.setDescription('Queries sent to the name server identified by this row\n               of the table are limited to those for names in the name\n               subtree identified by this variable.  If no such\n               limitation applies, the value of this variable is the\n               name of the root domain (a DNS name consisting of a\n               single zero octet).')
dnsResConfigSbeltClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 6), DnsClass())
if mibBuilder.loadTexts: dnsResConfigSbeltClass.setDescription('The class of DNS queries that will be sent to the server\n               identified by this row of the table.')
dnsResConfigSbeltStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 4, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dnsResConfigSbeltStatus.setDescription('Row status column for this row of the Sbelt table.')
dnsResConfigUpTime = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 5), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResConfigUpTime.setDescription('If the resolver has a persistent state (e.g., a\n               process), this value will be the time elapsed since it\n               started.  For software without persistant state, this\n               value will be 0.')
dnsResConfigResetTime = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 6), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResConfigResetTime.setDescription("If the resolver has a persistent state (e.g., a process)\n               and supports a `reset' operation (e.g., can be told to\n               re-read configuration files), this value will be the\n               time elapsed since the last time the resolver was\n               `reset.'  For software that does not have persistence or\n               does not support a `reset' operation, this value will be\n               zero.")
dnsResConfigReset = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("reset", 2), ("initializing", 3), ("running", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResConfigReset.setDescription('Status/action object to reinitialize any persistant\n               resolver state.  When set to reset(2), any persistant\n               resolver state (such as a process) is reinitialized as if\n               the resolver had just been started.  This value will\n               never be returned by a read operation.  When read, one of\n               the following values will be returned:\n                   other(1) - resolver in some unknown state;\n                   initializing(3) - resolver (re)initializing;\n                   running(4) - resolver currently running.')
dnsResCounterByOpcodeTable = MibTable((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 3), )
if mibBuilder.loadTexts: dnsResCounterByOpcodeTable.setDescription('Table of the current count of resolver queries and\n               answers.')
dnsResCounterByOpcodeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 3, 1), ).setIndexNames((0, "DNS-RESOLVER-MIB", "dnsResCounterByOpcodeCode"))
if mibBuilder.loadTexts: dnsResCounterByOpcodeEntry.setDescription('Entry in the resolver counter table.  Entries are\n               indexed by DNS OpCode.')
dnsResCounterByOpcodeCode = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 3, 1, 1), DnsOpCode())
if mibBuilder.loadTexts: dnsResCounterByOpcodeCode.setDescription('The index to this table.  The OpCodes that have already\n               been defined are found in RFC-1035.')
dnsResCounterByOpcodeQueries = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterByOpcodeQueries.setDescription('Total number of queries that have sent out by the\n               resolver since initialization for the OpCode which is\n               the index to this row of the table.')
dnsResCounterByOpcodeResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 3, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterByOpcodeResponses.setDescription('Total number of responses that have been received by the\n               resolver since initialization for the OpCode which is\n               the index to this row of the table.')
dnsResCounterByRcodeTable = MibTable((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 4), )
if mibBuilder.loadTexts: dnsResCounterByRcodeTable.setDescription('Table of the current count of responses to resolver\n               queries.')
dnsResCounterByRcodeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 4, 1), ).setIndexNames((0, "DNS-RESOLVER-MIB", "dnsResCounterByRcodeCode"))
if mibBuilder.loadTexts: dnsResCounterByRcodeEntry.setDescription('Entry in the resolver response table.  Entries are\n               indexed by DNS response code.')
dnsResCounterByRcodeCode = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 4, 1, 1), DnsRespCode())
if mibBuilder.loadTexts: dnsResCounterByRcodeCode.setDescription('The index to this table.  The Response Codes that have\n               already been defined are found in RFC-1035.')
dnsResCounterByRcodeResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 4, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterByRcodeResponses.setDescription('Number of responses the resolver has received for the\n               response code value which identifies this row of the\n               table.')
dnsResCounterNonAuthDataResps = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterNonAuthDataResps.setDescription('Number of requests made by the resolver for which a\n               non-authoritative answer (cached data) was received.')
dnsResCounterNonAuthNoDataResps = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterNonAuthNoDataResps.setDescription('Number of requests made by the resolver for which a\n               non-authoritative answer - no such data response (empty\n               answer) was received.')
dnsResCounterMartians = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterMartians.setDescription('Number of responses received which were received from\n               servers that the resolver does not think it asked.')
dnsResCounterRecdResponses = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterRecdResponses.setDescription('Number of responses received to all queries.')
dnsResCounterUnparseResps = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterUnparseResps.setDescription('Number of responses received which were unparseable.')
dnsResCounterFallbacks = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 2, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCounterFallbacks.setDescription('Number of times the resolver had to fall back to its\n               seat belt information.')
dnsResLameDelegationOverflows = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResLameDelegationOverflows.setDescription('Number of times the resolver attempted to add an entry\n               to the Lame Delegation table but was unable to for some\n               reason such as space constraints.')
dnsResLameDelegationTable = MibTable((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2), )
if mibBuilder.loadTexts: dnsResLameDelegationTable.setDescription('Table of name servers returning lame delegations.\n\n               A lame delegation has occured when a parent zone\n               delegates authority for a child zone to a server that\n               appears not to think that it is authoritative for the\n               child zone in question.')
dnsResLameDelegationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2, 1), ).setIndexNames((0, "DNS-RESOLVER-MIB", "dnsResLameDelegationSource"), (0, "DNS-RESOLVER-MIB", "dnsResLameDelegationName"), (0, "DNS-RESOLVER-MIB", "dnsResLameDelegationClass"))
if mibBuilder.loadTexts: dnsResLameDelegationEntry.setDescription('Entry in lame delegation table.  Only the resolver may\n               create rows in this table.  SNMP SET requests may be used\n               to delete rows.')
dnsResLameDelegationSource = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2, 1, 1), IpAddress())
if mibBuilder.loadTexts: dnsResLameDelegationSource.setDescription('Source of lame delegation.')
dnsResLameDelegationName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2, 1, 2), DnsNameAsIndex())
if mibBuilder.loadTexts: dnsResLameDelegationName.setDescription('DNS name for which lame delegation was received.')
dnsResLameDelegationClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2, 1, 3), DnsClass())
if mibBuilder.loadTexts: dnsResLameDelegationClass.setDescription('DNS class of received lame delegation.')
dnsResLameDelegationCounts = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResLameDelegationCounts.setDescription('How many times this lame delegation has been received.')
dnsResLameDelegationStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 3, 2, 1, 5), RowStatus()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResLameDelegationStatus.setDescription('Status column for the lame delegation table.  Since only\n               the agent (DNS resolver) creates rows in this table, the\n               only values that a manager may write to this variable\n               are active(1) and destroy(6).')
dnsResCacheStatus = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("clear", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResCacheStatus.setDescription("Status/action for the resolver's cache.\n\n               enabled(1) means that the use of the cache is allowed.\n               Query operations can return this state.\n\n               disabled(2) means that the cache is not being used.\n               Query operations can return this state.\n\n               Setting this variable to clear(3) deletes the entire\n               contents of the resolver's cache, but does not otherwise\n               change the resolver's state.  The status will retain its\n               previous value from before the clear operation (i.e.,\n               enabled(1) or disabled(2)).  The value of clear(3) can\n               NOT be returned by a query operation.")
dnsResCacheMaxTTL = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 2), DnsTime()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResCacheMaxTTL.setDescription('Maximum Time-To-Live for RRs in this cache.  If the\n               resolver does not implement a TTL ceiling, the value of\n               this field should be zero.')
dnsResCacheGoodCaches = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheGoodCaches.setDescription('Number of RRs the resolver has cached successfully.')
dnsResCacheBadCaches = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheBadCaches.setDescription("Number of RRs the resolver has refused to cache because\n               they appear to be dangerous or irrelevant.  E.g., RRs\n               with suspiciously high TTLs, unsolicited root\n               information, or that just don't appear to be relevant to\n               the question the resolver asked.")
dnsResCacheRRTable = MibTable((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5), )
if mibBuilder.loadTexts: dnsResCacheRRTable.setDescription("This table contains information about all the resource\n               records currently in the resolver's cache.")
dnsResCacheRREntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1), ).setIndexNames((0, "DNS-RESOLVER-MIB", "dnsResCacheRRName"), (0, "DNS-RESOLVER-MIB", "dnsResCacheRRClass"), (0, "DNS-RESOLVER-MIB", "dnsResCacheRRType"), (0, "DNS-RESOLVER-MIB", "dnsResCacheRRIndex"))
if mibBuilder.loadTexts: dnsResCacheRREntry.setDescription("An entry in the resolvers's cache.  Rows may be created\n               only by the resolver.  SNMP SET requests may be used to\n               delete rows.")
dnsResCacheRRName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 1), DnsNameAsIndex())
if mibBuilder.loadTexts: dnsResCacheRRName.setDescription('Owner name of the Resource Record in the cache which is\n               identified in this row of the table.  As described in\n               RFC-1034, the owner of the record is the domain name\n               were the RR is found.')
dnsResCacheRRClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 2), DnsClass())
if mibBuilder.loadTexts: dnsResCacheRRClass.setDescription('DNS class of the Resource Record in the cache which is\n               identified in this row of the table.')
dnsResCacheRRType = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 3), DnsType())
if mibBuilder.loadTexts: dnsResCacheRRType.setDescription('DNS type of the Resource Record in the cache which is\n               identified in this row of the table.')
dnsResCacheRRTTL = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 4), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheRRTTL.setDescription('Time-To-Live of RR in DNS cache.  This is the initial\n               TTL value which was received with the RR when it was\n               originally received.')
dnsResCacheRRElapsedTTL = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 5), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheRRElapsedTTL.setDescription('Elapsed seconds since RR was received.')
dnsResCacheRRSource = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 6), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheRRSource.setDescription('Host from which RR was received, 0.0.0.0 if unknown.')
dnsResCacheRRData = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 7), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheRRData.setDescription('RDATA portion of a cached RR.  The value is in the\n               format defined for the particular DNS class and type of\n               the resource record.')
dnsResCacheRRStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 8), RowStatus()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResCacheRRStatus.setDescription('Status column for the resolver cache table.  Since only\n               the agent (DNS resolver) creates rows in this table, the\n               only values that a manager may write to this variable\n               are active(1) and destroy(6).')
dnsResCacheRRIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 9), Integer32())
if mibBuilder.loadTexts: dnsResCacheRRIndex.setDescription('A value which makes entries in the table unique when the\n               other index values (dnsResCacheRRName,\n               dnsResCacheRRClass, and dnsResCacheRRType) do not\n               provide a unique index.')
dnsResCacheRRPrettyName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 4, 5, 1, 10), DnsName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResCacheRRPrettyName.setDescription('Name of the RR at this row in the table.  This is\n               identical to the dnsResCacheRRName variable, except that\n               character case is preserved in this variable, per DNS\n               conventions.')
dnsResNCacheStatus = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("clear", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResNCacheStatus.setDescription("Status/action for the resolver's negative response\n               cache.\n\n               enabled(1) means that the use of the negative response\n               cache is allowed.  Query operations can return this\n               state.\n\n               disabled(2) means that the negative response cache is\n               not being used.  Query operations can return this state.\n\n               Setting this variable to clear(3) deletes the entire\n               contents of the resolver's negative response cache.  The\n               status will retain its previous value from before the\n               clear operation (i.e., enabled(1) or disabled(2)).  The\n               value of clear(3) can NOT be returned by a query\n               operation.")
dnsResNCacheMaxTTL = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 2), DnsTime()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResNCacheMaxTTL.setDescription('Maximum Time-To-Live for cached authoritative errors.\n               If the resolver does not implement a TTL ceiling, the\n               value of this field should be zero.')
dnsResNCacheGoodNCaches = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheGoodNCaches.setDescription('Number of authoritative errors the resolver has cached\n               successfully.')
dnsResNCacheBadNCaches = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheBadNCaches.setDescription('Number of authoritative errors the resolver would have\n               liked to cache but was unable to because the appropriate\n               SOA RR was not supplied or looked suspicious.')
dnsResNCacheErrTable = MibTable((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5), )
if mibBuilder.loadTexts: dnsResNCacheErrTable.setDescription("The resolver's negative response cache.  This table\n               contains information about authoritative errors that\n               have been cached by the resolver.")
dnsResNCacheErrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1), ).setIndexNames((0, "DNS-RESOLVER-MIB", "dnsResNCacheErrQName"), (0, "DNS-RESOLVER-MIB", "dnsResNCacheErrQClass"), (0, "DNS-RESOLVER-MIB", "dnsResNCacheErrQType"), (0, "DNS-RESOLVER-MIB", "dnsResNCacheErrIndex"))
if mibBuilder.loadTexts: dnsResNCacheErrEntry.setDescription("An entry in the resolver's negative response cache\n               table.  Only the resolver can create rows.  SNMP SET\n               requests may be used to delete rows.")
dnsResNCacheErrQName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 1), DnsNameAsIndex())
if mibBuilder.loadTexts: dnsResNCacheErrQName.setDescription('QNAME associated with a cached authoritative error.')
dnsResNCacheErrQClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 2), DnsQClass())
if mibBuilder.loadTexts: dnsResNCacheErrQClass.setDescription('DNS QCLASS associated with a cached authoritative\n               error.')
dnsResNCacheErrQType = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 3), DnsQType())
if mibBuilder.loadTexts: dnsResNCacheErrQType.setDescription('DNS QTYPE associated with a cached authoritative error.')
dnsResNCacheErrTTL = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 4), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheErrTTL.setDescription('Time-To-Live of a cached authoritative error at the time\n               of the error, it should not be decremented by the number\n               of seconds since it was received.  This should be the\n               TTL as copied from the MINIMUM field of the SOA that\n               accompanied the authoritative error, or a smaller value\n               if the resolver implements a ceiling on negative\n               response cache TTLs.')
dnsResNCacheErrElapsedTTL = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 5), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheErrElapsedTTL.setDescription('Elapsed seconds since authoritative error was received.')
dnsResNCacheErrSource = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 6), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheErrSource.setDescription('Host which sent the authoritative error, 0.0.0.0 if\n               unknown.')
dnsResNCacheErrCode = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("nonexistantName", 1), ("noData", 2), ("other", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheErrCode.setDescription('The authoritative error that has been cached:\n\n               nonexistantName(1) indicates an authoritative name error\n               (RCODE = 3).\n\n               noData(2) indicates an authoritative response with no\n               error (RCODE = 0) and no relevant data.\n\n               other(3) indicates some other cached authoritative\n               error.  At present, no such errors are known to exist.')
dnsResNCacheErrStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 8), RowStatus()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsResNCacheErrStatus.setDescription('Status column for the resolver negative response cache\n               table.  Since only the agent (DNS resolver) creates rows\n               in this table, the only values that a manager may write\n               to this variable are active(1) and destroy(6).')
dnsResNCacheErrIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 9), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheErrIndex.setDescription('A value which makes entries in the table unique when the\n               other index values (dnsResNCacheErrQName,\n               dnsResNCacheErrQClass, and dnsResNCacheErrQType) do not\n               provide a unique index.')
dnsResNCacheErrPrettyName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 2, 1, 5, 5, 1, 10), DnsName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResNCacheErrPrettyName.setDescription('QNAME associated with this row in the table.  This is\n               identical to the dnsResNCacheErrQName variable, except\n               that character case is preserved in this variable, per\n               DNS conventions.')
dnsResOptCounterReferals = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 6, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResOptCounterReferals.setDescription('Number of responses which were received from servers\n               redirecting query to another server.')
dnsResOptCounterRetrans = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 6, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResOptCounterRetrans.setDescription('Number requests retransmitted for all reasons.')
dnsResOptCounterNoResponses = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 6, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResOptCounterNoResponses.setDescription('Number of queries that were retransmitted because of no\n               response.')
dnsResOptCounterRootRetrans = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 6, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResOptCounterRootRetrans.setDescription('Number of queries that were retransmitted that were to\n               root servers.')
dnsResOptCounterInternals = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 6, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResOptCounterInternals.setDescription('Number of requests internally generated by the\n               resolver.')
dnsResOptCounterInternalTimeOuts = MibScalar((1, 3, 6, 1, 2, 1, 32, 2, 1, 6, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsResOptCounterInternalTimeOuts.setDescription('Number of requests internally generated which timed\n               out.')
dnsResMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 2))
dnsResConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 2, 2, 1)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResConfigImplementIdent"), ("DNS-RESOLVER-MIB", "dnsResConfigService"), ("DNS-RESOLVER-MIB", "dnsResConfigMaxCnames"), ("DNS-RESOLVER-MIB", "dnsResConfigSbeltName"), ("DNS-RESOLVER-MIB", "dnsResConfigSbeltRecursion"), ("DNS-RESOLVER-MIB", "dnsResConfigSbeltPref"), ("DNS-RESOLVER-MIB", "dnsResConfigSbeltStatus"), ("DNS-RESOLVER-MIB", "dnsResConfigUpTime"), ("DNS-RESOLVER-MIB", "dnsResConfigResetTime"), ("DNS-RESOLVER-MIB", "dnsResConfigReset"),))
if mibBuilder.loadTexts: dnsResConfigGroup.setDescription('A collection of objects providing basic configuration\n               information for a DNS resolver implementation.')
dnsResCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 2, 2, 2)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResCounterByOpcodeQueries"), ("DNS-RESOLVER-MIB", "dnsResCounterByOpcodeResponses"), ("DNS-RESOLVER-MIB", "dnsResCounterByRcodeResponses"), ("DNS-RESOLVER-MIB", "dnsResCounterNonAuthDataResps"), ("DNS-RESOLVER-MIB", "dnsResCounterNonAuthNoDataResps"), ("DNS-RESOLVER-MIB", "dnsResCounterMartians"), ("DNS-RESOLVER-MIB", "dnsResCounterRecdResponses"), ("DNS-RESOLVER-MIB", "dnsResCounterUnparseResps"), ("DNS-RESOLVER-MIB", "dnsResCounterFallbacks"),))
if mibBuilder.loadTexts: dnsResCounterGroup.setDescription('A collection of objects providing basic instrumentation\n               of a DNS resolver implementation.')
dnsResLameDelegationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 2, 2, 3)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResLameDelegationOverflows"), ("DNS-RESOLVER-MIB", "dnsResLameDelegationCounts"), ("DNS-RESOLVER-MIB", "dnsResLameDelegationStatus"),))
if mibBuilder.loadTexts: dnsResLameDelegationGroup.setDescription("A collection of objects providing instrumentation of\n               `lame delegation' failures.")
dnsResCacheGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 2, 2, 4)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResCacheStatus"), ("DNS-RESOLVER-MIB", "dnsResCacheMaxTTL"), ("DNS-RESOLVER-MIB", "dnsResCacheGoodCaches"), ("DNS-RESOLVER-MIB", "dnsResCacheBadCaches"), ("DNS-RESOLVER-MIB", "dnsResCacheRRTTL"), ("DNS-RESOLVER-MIB", "dnsResCacheRRElapsedTTL"), ("DNS-RESOLVER-MIB", "dnsResCacheRRSource"), ("DNS-RESOLVER-MIB", "dnsResCacheRRData"), ("DNS-RESOLVER-MIB", "dnsResCacheRRStatus"), ("DNS-RESOLVER-MIB", "dnsResCacheRRPrettyName"),))
if mibBuilder.loadTexts: dnsResCacheGroup.setDescription("A collection of objects providing access to and control\n               of a DNS resolver's cache.")
dnsResNCacheGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 2, 2, 5)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResNCacheStatus"), ("DNS-RESOLVER-MIB", "dnsResNCacheMaxTTL"), ("DNS-RESOLVER-MIB", "dnsResNCacheGoodNCaches"), ("DNS-RESOLVER-MIB", "dnsResNCacheBadNCaches"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrTTL"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrElapsedTTL"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrSource"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrCode"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrStatus"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrIndex"), ("DNS-RESOLVER-MIB", "dnsResNCacheErrPrettyName"),))
if mibBuilder.loadTexts: dnsResNCacheGroup.setDescription("A collection of objects providing access to and control\n               of a DNS resolver's negative response cache.")
dnsResOptCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 2, 2, 6)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResOptCounterReferals"), ("DNS-RESOLVER-MIB", "dnsResOptCounterRetrans"), ("DNS-RESOLVER-MIB", "dnsResOptCounterNoResponses"), ("DNS-RESOLVER-MIB", "dnsResOptCounterRootRetrans"), ("DNS-RESOLVER-MIB", "dnsResOptCounterInternals"), ("DNS-RESOLVER-MIB", "dnsResOptCounterInternalTimeOuts"),))
if mibBuilder.loadTexts: dnsResOptCounterGroup.setDescription('A collection of objects providing further\n               instrumentation applicable to many but not all DNS\n               resolvers.')
dnsResMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 2, 3))
dnsResMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 32, 2, 3, 1)).setObjects(*(("DNS-RESOLVER-MIB", "dnsResConfigGroup"), ("DNS-RESOLVER-MIB", "dnsResCounterGroup"), ("DNS-RESOLVER-MIB", "dnsResCacheGroup"), ("DNS-RESOLVER-MIB", "dnsResNCacheGroup"), ("DNS-RESOLVER-MIB", "dnsResLameDelegationGroup"), ("DNS-RESOLVER-MIB", "dnsResOptCounterGroup"),))
if mibBuilder.loadTexts: dnsResMIBCompliance.setDescription('The compliance statement for agents implementing the DNS\n               resolver MIB extensions.')
mibBuilder.exportSymbols("DNS-RESOLVER-MIB", dnsResNCacheErrStatus=dnsResNCacheErrStatus, dnsResCounterByOpcodeCode=dnsResCounterByOpcodeCode, dnsResCacheBadCaches=dnsResCacheBadCaches, dnsResLameDelegationStatus=dnsResLameDelegationStatus, dnsResConfigSbeltStatus=dnsResConfigSbeltStatus, dnsResNCacheErrTTL=dnsResNCacheErrTTL, dnsResOptCounterInternalTimeOuts=dnsResOptCounterInternalTimeOuts, dnsResCounterMartians=dnsResCounterMartians, dnsResCacheRRSource=dnsResCacheRRSource, dnsResNCacheStatus=dnsResNCacheStatus, dnsResCounter=dnsResCounter, dnsResConfigSbeltAddr=dnsResConfigSbeltAddr, dnsResConfigImplementIdent=dnsResConfigImplementIdent, dnsResOptCounterRetrans=dnsResOptCounterRetrans, dnsResConfigService=dnsResConfigService, dnsResCounterByRcodeEntry=dnsResCounterByRcodeEntry, dnsResNCacheErrQClass=dnsResNCacheErrQClass, dnsResNCacheGroup=dnsResNCacheGroup, dnsResNCacheErrQType=dnsResNCacheErrQType, dnsResLameDelegationGroup=dnsResLameDelegationGroup, dnsResCounterByRcodeCode=dnsResCounterByRcodeCode, dnsResMIB=dnsResMIB, dnsResCacheRRTTL=dnsResCacheRRTTL, dnsResNCacheMaxTTL=dnsResNCacheMaxTTL, dnsResOptCounterRootRetrans=dnsResOptCounterRootRetrans, dnsResOptCounterGroup=dnsResOptCounterGroup, dnsResNCacheErrQName=dnsResNCacheErrQName, dnsResLameDelegationSource=dnsResLameDelegationSource, dnsResCounterFallbacks=dnsResCounterFallbacks, dnsResConfigSbeltEntry=dnsResConfigSbeltEntry, dnsResCacheRRType=dnsResCacheRRType, dnsResConfigResetTime=dnsResConfigResetTime, dnsResCacheRRName=dnsResCacheRRName, dnsResConfigMaxCnames=dnsResConfigMaxCnames, dnsResCache=dnsResCache, dnsResCounterByRcodeResponses=dnsResCounterByRcodeResponses, dnsResLameDelegationName=dnsResLameDelegationName, dnsResLameDelegationEntry=dnsResLameDelegationEntry, PYSNMP_MODULE_ID=dnsResMIB, dnsResCounterGroup=dnsResCounterGroup, dnsResCounterByOpcodeQueries=dnsResCounterByOpcodeQueries, dnsResLameDelegationTable=dnsResLameDelegationTable, dnsResConfigSbeltSubTree=dnsResConfigSbeltSubTree, dnsResCacheMaxTTL=dnsResCacheMaxTTL, DnsQClass=DnsQClass, dnsResCacheRREntry=dnsResCacheRREntry, dnsResCounterNonAuthNoDataResps=dnsResCounterNonAuthNoDataResps, dnsResMIBCompliance=dnsResMIBCompliance, dnsResNCacheErrCode=dnsResNCacheErrCode, dnsResNCacheErrIndex=dnsResNCacheErrIndex, dnsResMIBCompliances=dnsResMIBCompliances, dnsResCounterByOpcodeResponses=dnsResCounterByOpcodeResponses, dnsResCacheGroup=dnsResCacheGroup, dnsResCacheRRStatus=dnsResCacheRRStatus, dnsResConfigSbeltClass=dnsResConfigSbeltClass, dnsResConfigUpTime=dnsResConfigUpTime, dnsResCounterRecdResponses=dnsResCounterRecdResponses, dnsResCounterByOpcodeEntry=dnsResCounterByOpcodeEntry, dnsResCounterByRcodeTable=dnsResCounterByRcodeTable, dnsResCacheRRData=dnsResCacheRRData, dnsResConfigSbeltName=dnsResConfigSbeltName, dnsResNCacheErrTable=dnsResNCacheErrTable, dnsResConfigGroup=dnsResConfigGroup, dnsResCacheRRClass=dnsResCacheRRClass, DnsQType=DnsQType, dnsResMIBGroups=dnsResMIBGroups, dnsResConfig=dnsResConfig, DnsRespCode=DnsRespCode, dnsResLameDelegation=dnsResLameDelegation, dnsResNCacheGoodNCaches=dnsResNCacheGoodNCaches, dnsResCacheRRIndex=dnsResCacheRRIndex, dnsResCacheRRPrettyName=dnsResCacheRRPrettyName, dnsResCacheRRElapsedTTL=dnsResCacheRRElapsedTTL, dnsResNCache=dnsResNCache, dnsResCacheGoodCaches=dnsResCacheGoodCaches, dnsResOptCounterNoResponses=dnsResOptCounterNoResponses, dnsResCacheStatus=dnsResCacheStatus, dnsResNCacheBadNCaches=dnsResNCacheBadNCaches, dnsResOptCounterInternals=dnsResOptCounterInternals, dnsResMIBObjects=dnsResMIBObjects, dnsResLameDelegationOverflows=dnsResLameDelegationOverflows, dnsResConfigSbeltRecursion=dnsResConfigSbeltRecursion, dnsResConfigReset=dnsResConfigReset, dnsResCacheRRTable=dnsResCacheRRTable, dnsResOptCounterReferals=dnsResOptCounterReferals, dnsResConfigSbeltTable=dnsResConfigSbeltTable, dnsResNCacheErrPrettyName=dnsResNCacheErrPrettyName, dnsResNCacheErrEntry=dnsResNCacheErrEntry, dnsResLameDelegationClass=dnsResLameDelegationClass, dnsResConfigSbeltPref=dnsResConfigSbeltPref, dnsResLameDelegationCounts=dnsResLameDelegationCounts, dnsResNCacheErrElapsedTTL=dnsResNCacheErrElapsedTTL, dnsResCounterUnparseResps=dnsResCounterUnparseResps, dnsResNCacheErrSource=dnsResNCacheErrSource, dnsResOptCounter=dnsResOptCounter, dnsResCounterByOpcodeTable=dnsResCounterByOpcodeTable, dnsResCounterNonAuthDataResps=dnsResCounterNonAuthDataResps)



#
# PySNMP MIB module COFFEE-POT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/COFFEE-POT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter64, MibIdentifier, TimeTicks, ObjectIdentity, Unsigned32, NotificationType, Bits, Gauge32, Integer32, transmission, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, iso, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "MibIdentifier", "TimeTicks", "ObjectIdentity", "Unsigned32", "NotificationType", "Bits", "Gauge32", "Integer32", "transmission", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "iso", "ModuleIdentity")
( TextualConvention, TimeInterval, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "TimeInterval", "DisplayString", "TimeStamp")
coffee = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 132))
if mibBuilder.loadTexts: coffee.setLastUpdated('9803231700Z')
if mibBuilder.loadTexts: coffee.setOrganization('Networked Appliance Management Working Group')
if mibBuilder.loadTexts: coffee.setContactInfo('        Michael Slavitch\n                        Loran Technologies,\n                        955 Green Valley Crescent\n                        Ottawa, Ontario Canada K2A 0B6\n\n                   Tel: 613-723-7505\n                   Fax: 613-723-7209\n                E-mail: slavitch@loran.com')
if mibBuilder.loadTexts: coffee.setDescription('The MIB Module for coffee vending devices.')
potName = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: potName.setDescription('The vendor description of the pot under management')
potCapacity = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: potCapacity.setDescription('The number of units of beverage supported by this device\n            (regardless of its current state) .')
potType = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("automatic-drip", 1), ("percolator", 2), ("french-press", 3), ("espresso", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: potType.setDescription('The brew type of the coffee pot.')
potLocation = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 4), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: potLocation.setDescription('The physical location of the pot in question')
potMonitor = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 132, 6))
potOperStatus = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 6, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("off", 1), ("brewing", 2), ("holding", 3), ("other", 4), ("waiting", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: potOperStatus.setDescription('The operating status of the pot in question. Note\n                 that this is a read-only feature. Current hardware\n                 prevents us from changing the port state via SNMP.')
potLevel = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 6, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: potLevel.setDescription('The number of units of coffee under management. The\n                 units of level are defined in potMetric below.')
potMetric = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 6, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("espresso", 1), ("demi-tasse", 2), ("cup", 3), ("mug", 4), ("bucket", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: potMetric.setDescription('The vendor description of the pot under management')
potStartTime = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 6, 4), Integer32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: potStartTime.setDescription('The time in seconds since Jan 1 1970 to start the pot\n                if and only if potOperStatus is waiting(5)')
lastStartTime = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 6, 5), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: lastStartTime.setDescription('The amount of time, in TimeTicks, since the coffee\n               making process was initiated.')
potTemperature = MibScalar((1, 3, 6, 1, 2, 1, 10, 132, 6, 6), Integer32()).setUnits('degrees Centigrade').setMaxAccess("readonly")
if mibBuilder.loadTexts: potTemperature.setDescription('The ambient temperature of the coffee within the pot')
mibBuilder.exportSymbols("COFFEE-POT-MIB", potLocation=potLocation, potLevel=potLevel, potType=potType, PYSNMP_MODULE_ID=coffee, potMonitor=potMonitor, coffee=coffee, potStartTime=potStartTime, potTemperature=potTemperature, potMetric=potMetric, potName=potName, potOperStatus=potOperStatus, potCapacity=potCapacity, lastStartTime=lastStartTime)



#
# PySNMP MIB module DIFFSERV-CONFIG-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DIFFSERV-CONFIG-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:26 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Counter64, IpAddress, TimeTicks, Counter32, iso, zeroDotZero, Unsigned32, mib_2, NotificationType, ModuleIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, Integer32, Bits, Gauge32, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "IpAddress", "TimeTicks", "Counter32", "iso", "zeroDotZero", "Unsigned32", "mib-2", "NotificationType", "ModuleIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "Integer32", "Bits", "Gauge32", "ObjectIdentity")
( StorageType, DateAndTime, RowPointer, TextualConvention, DisplayString, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "DateAndTime", "RowPointer", "TextualConvention", "DisplayString", "RowStatus")
diffServConfigMib = ModuleIdentity((1, 3, 6, 1, 2, 1, 108)).setRevisions(("2004-01-22 00:00",))
if mibBuilder.loadTexts: diffServConfigMib.setLastUpdated('200401220000Z')
if mibBuilder.loadTexts: diffServConfigMib.setOrganization('SNMPCONF WG')
if mibBuilder.loadTexts: diffServConfigMib.setContactInfo('SNMPCONF Working Group\n        http://www.ietf.org/html.charters/snmpconf-charter.html\n        WG mailing list: snmpconf@snmp.com\n\n        Editors:\n        Harrie Hazewinkel\n        I.Net\n        via Darwin 85\n        20019 - Settimo Milanese (MI)\n        Italy\n        EMail: harrie@inet.it\n\n        David Partain\n        Ericsson AB\n        P.O. Box 1248\n        SE-581 12 Linkoping\n        Sweden\n        E-mail: David.Partain@ericsson.com')
if mibBuilder.loadTexts: diffServConfigMib.setDescription("This MIB module contains differentiated services\n        specific managed objects to perform higher-level\n        configuration management.  This MIB allows policies\n        to use 'templates' to instantiate Differentiated\n        Services functional datapath configurations to\n        be assigned (associated with an interface and\n        direction) when a policy is activated.\n\n        Copyright (C) The Internet Society (2004).  This version\n        of this MIB module is part of RFC 3747;  see the RFC\n        itself for full legal notices.")
diffServConfigMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 108, 1))
diffServConfigMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 108, 2))
diffServConfigTable = MibTable((1, 3, 6, 1, 2, 1, 108, 1, 2), )
if mibBuilder.loadTexts: diffServConfigTable.setDescription("A table which defines the various per-hop-behaviors\n       for which the system has default 'templates'.")
diffServConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 108, 1, 2, 1), ).setIndexNames((0, "DIFFSERV-CONFIG-MIB", "diffServConfigId"))
if mibBuilder.loadTexts: diffServConfigEntry.setDescription('An entry defining a per-hop-behavior.  Each entry in\n       this table combines the various parameters (entries)\n       into a specific per-hop-behavior.  Entries in this\n       table might be defined by a vendor (pre-configured)\n       or defined by a management application.')
diffServConfigId = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,116)))
if mibBuilder.loadTexts: diffServConfigId.setDescription('A unique id for the per-hop-behavior policy for at\n       least the SNMP agent.  For ease of administration the\n       value may be unique within an administrative domain,\n       but this is not required.\n\n       The range of up to 116 octets is chosen to stay within\n       the SMI limit of 128 sub-identifiers in an object\n       identifier.')
diffServConfigDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 2), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServConfigDescr.setDescription("A human-readable description to identify this defined\n       per-hop-behavior.  Note that this is an SnmpAdminString,\n       which permits UTF-8 strings.  An administratively assigned\n       identifier for a template that would be unique within\n       an administrative domain.  It is up to the management\n       applications to agree how these are assigned within the\n       administrative domain.  Once a description, such as\n       'EF' is assigned, that has a certain set of parameters\n       that achieve 'EF' from box to box. Management\n       application code or script code can then scan\n       the table to find the proper template and then\n       assign it.")
diffServConfigOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 3), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServConfigOwner.setDescription('The owner who created this entry.')
diffServConfigLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: diffServConfigLastChange.setDescription('The date and time when this entry was last changed.')
diffServConfigStart = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 5), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServConfigStart.setDescription('The pointer to a functional datapath configuration template as\n       set up in the DIFFSERV-MIB.  This RowPointer should\n       point to an instance of one of:\n         diffServClfrEntry\n         diffServMeterEntry\n         diffServActionEntry\n         diffServAlgDropEntry\n         diffServQEntry\n\n\n       A value of zeroDotZero in this attribute indicates no\n       further Diffserv treatment is performed on traffic of\n       this functional datapath.  This also means that the\n       template described by this row is not defined.\n\n       If the row pointed to does not exist, the treatment\n       is as if this attribute contains a value of zeroDotZero.')
diffServConfigStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 6), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServConfigStorage.setDescription("The type of storage used for this row.\n\n       Since an entry in this table serves as a starting\n       point for a configuration, it is recommended that\n       all entries comprising the configuration started by\n       diffServConfigStart follow the storage type of this\n       entry.  Otherwise, after agent reboots a configuration\n       may differ.  It may very well be that the agent is\n       not capable of detecting such changes and therefore,\n       the management application should verify the correct\n       configuration after a reboot.  Rows with a StorageType\n       of 'permanent' do not need to allow write access to\n       any of the columnar objects in that row.")
diffServConfigStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 108, 1, 2, 1, 7), RowStatus().clone('notInService')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: diffServConfigStatus.setDescription('RowStatus object used for creation and deletion of\n       rows in this table.  All writable objects in this row\n       may be modified at any time.')
diffServConfigMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 108, 2, 1))
diffServConfigMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 108, 2, 2))
diffServConfigMIBFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 108, 2, 1, 1)).setObjects(*(("DIFFSERV-CONFIG-MIB", "diffServConfigMIBConfigGroup"),))
if mibBuilder.loadTexts: diffServConfigMIBFullCompliance.setDescription("The full compliance for this MIB module.\n\n       For this compliance level the 'diffServMIBFullCompliance'\n       must be met, since this MIB module depends on it in order\n       to provide the configuration entries.\n       ")
diffServConfigMIBConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 108, 2, 2, 1)).setObjects(*(("DIFFSERV-CONFIG-MIB", "diffServConfigDescr"), ("DIFFSERV-CONFIG-MIB", "diffServConfigOwner"), ("DIFFSERV-CONFIG-MIB", "diffServConfigLastChange"), ("DIFFSERV-CONFIG-MIB", "diffServConfigStart"), ("DIFFSERV-CONFIG-MIB", "diffServConfigStorage"), ("DIFFSERV-CONFIG-MIB", "diffServConfigStatus"),))
if mibBuilder.loadTexts: diffServConfigMIBConfigGroup.setDescription('The per-hop-behavior Group defines the MIB objects that\n       describe the configuration template for the per-hop-behavior.')
mibBuilder.exportSymbols("DIFFSERV-CONFIG-MIB", diffServConfigOwner=diffServConfigOwner, diffServConfigMIBConfigGroup=diffServConfigMIBConfigGroup, diffServConfigEntry=diffServConfigEntry, diffServConfigMib=diffServConfigMib, diffServConfigStatus=diffServConfigStatus, diffServConfigTable=diffServConfigTable, diffServConfigStart=diffServConfigStart, diffServConfigMIBGroups=diffServConfigMIBGroups, diffServConfigId=diffServConfigId, diffServConfigMIBConformance=diffServConfigMIBConformance, diffServConfigStorage=diffServConfigStorage, diffServConfigMIBCompliances=diffServConfigMIBCompliances, diffServConfigDescr=diffServConfigDescr, PYSNMP_MODULE_ID=diffServConfigMib, diffServConfigMIBFullCompliance=diffServConfigMIBFullCompliance, diffServConfigMIBObjects=diffServConfigMIBObjects, diffServConfigLastChange=diffServConfigLastChange)



#
# PySNMP MIB module MALLOC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MALLOC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:19:58 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsUnion")
( IANAmallocRangeSource, IANAscopeSource, ) = mibBuilder.importSymbols("IANA-MALLOC-MIB", "IANAmallocRangeSource", "IANAscopeSource")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( LanguageTag, ) = mibBuilder.importSymbols("IPMROUTE-STD-MIB", "LanguageTag")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Counter64, mib_2, iso, Bits, Integer32, IpAddress, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, ModuleIdentity, Counter32, Gauge32, TimeTicks, Unsigned32, ObjectIdentity, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "mib-2", "iso", "Bits", "Integer32", "IpAddress", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ModuleIdentity", "Counter32", "Gauge32", "TimeTicks", "Unsigned32", "ObjectIdentity", "NotificationType")
( StorageType, TextualConvention, TruthValue, DisplayString, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "TextualConvention", "TruthValue", "DisplayString", "RowStatus")
mallocMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 101)).setRevisions(("2003-06-09 00:00",))
if mibBuilder.loadTexts: mallocMIB.setLastUpdated('200306090000Z')
if mibBuilder.loadTexts: mallocMIB.setOrganization('IETF MALLOC Working Group')
if mibBuilder.loadTexts: mallocMIB.setContactInfo(' WG-EMail:   malloc@catarina.usc.edu\n              Subscribe:  malloc-request@catarina.usc.edu\n              Archive:    catarina.usc.edu/pub/multicast/malloc/\n\n              Co-chair/editor:\n              Dave Thaler\n              Microsoft Corporation\n              One Microsoft Way\n              Redmond, WA 98052\n              EMail: dthaler@microsoft.com\n\n              Co-chair:\n              Steve Hanna\n              Sun Microsystems, Inc.\n              One Network Drive\n              Burlington, MA 01803\n              EMail: steve.hanna@sun.com')
if mibBuilder.loadTexts: mallocMIB.setDescription('The MIB module for management of multicast address\n            allocation.\n\n            Copyright (C) The Internet Society (2003).  This version of\n            this MIB module is part of RFC 3559; see the RFC itself for\n            full legal notices.')
mallocMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 101, 1))
malloc = MibIdentifier((1, 3, 6, 1, 2, 1, 101, 1, 1))
madcap = MibIdentifier((1, 3, 6, 1, 2, 1, 101, 1, 2))
mallocCapabilities = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 1, 1), Bits().clone(namedValues=NamedValues(("startTime", 0), ("serverMobility", 1), ("retryAfter", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocCapabilities.setDescription('This object describes the capabilities which a client or\n            server supports.  The startTime bit indicates that\n            allocations with a future start time are supported.  The\n            serverMobility bit indicates that allocations can be renewed\n            or released from a server other than the one granting the\n            original allocation.  The retryAfter bit indicates support\n            for a waiting state where the client may check back at a\n            later time to get the status of its request.')
mallocScopeTable = MibTable((1, 3, 6, 1, 2, 1, 101, 1, 1, 2), )
if mibBuilder.loadTexts: mallocScopeTable.setDescription('The (conceptual) table containing information on multicast\n            scopes from which addresses may be allocated.  Entries in\n            this table may be dynamically discovered via some other\n\n\n\n            protocol, such as MZAP, or may be statically configured,\n            such as in an isolated network environment.  Each scope is\n            associated with a range of multicast addresses, and ranges\n            for different rows must be disjoint.')
mallocScopeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1), ).setIndexNames((0, "MALLOC-MIB", "mallocScopeAddressType"), (0, "MALLOC-MIB", "mallocScopeFirstAddress"))
if mibBuilder.loadTexts: mallocScopeEntry.setDescription('An entry (conceptual row) containing the information on a\n            particular multicast scope.')
mallocScopeAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 1), InetAddressType())
if mibBuilder.loadTexts: mallocScopeAddressType.setDescription('The type of the addresses in the multicast scope range.\n            Legal values correspond to the subset of address families\n            for which multicast address allocation is supported.')
mallocScopeFirstAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 2), InetAddress().subtype(subtypeSpec=ValueSizeConstraint(0,20)))
if mibBuilder.loadTexts: mallocScopeFirstAddress.setDescription('The first address in the multicast scope range.  The type\n            of this address is determined by the value of the\n            mallocScopeAddressType object.')
mallocScopeLastAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 3), InetAddress().subtype(subtypeSpec=ValueSizeConstraint(0,20))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeLastAddress.setDescription('The last address in the multicast scope range.  The type of\n            this address is determined by the value of the\n            mallocScopeAddressType object.')
mallocScopeHopLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255)).clone(255)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeHopLimit.setDescription('The default IPv4 TTL or IPv6 hop limit which applications\n            should use for groups within the scope.')
mallocScopeStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeStatus.setDescription("The status of this row, by which new entries may be\n            created, or old entries deleted from this table.  If write\n            access is supported, the other writable objects in this\n            table may be modified even while the status is `active'.")
mallocScopeSource = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 6), IANAscopeSource()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocScopeSource.setDescription('The method by which this entry was learned.')
mallocScopeDivisible = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 7), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeDivisible.setDescription('If false, the server may allocate addresses out of the\n            entire range.  If true, the server must not allocate\n\n\n\n            addresses out of the entire range, but may only allocate\n            addresses out of a subrange learned via another method.\n            Creating or deleting a scope which is not divisible has the\n            side effect of creating or deleting the corresponding entry\n            in the mallocAllocRangeTable.  Deleting a scope which is\n            divisible has the side effect of deleting any corresponding\n            entries in the mallocAllocRangeTable, and the\n            mallocRequestTable.')
mallocScopeServerAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 8), InetAddressType().clone('unknown')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeServerAddressType.setDescription('The type of the address of a multicast address allocation\n            server to which a request may be sent.')
mallocScopeServerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 9), InetAddress().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeServerAddress.setDescription('The address of a multicast address allocation server to\n            which a request may be sent.  The default value is an zero-\n            length address, indicating that no server is known.  The\n            type of this address is determined by the value of the\n            mallocScopeServerAddressType object.')
mallocScopeSSM = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 10), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeSSM.setDescription('Indicates whether the scope is a Source-Specific Multicast\n            (SSM) range.')
mallocScopeStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 2, 1, 11), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeStorage.setDescription("The storage type for this conceptual row.  Conceptual rows\n            having the value 'permanent' need not allow write-access to\n            any columnar objects in the row.")
mallocScopeNameTable = MibTable((1, 3, 6, 1, 2, 1, 101, 1, 1, 3), )
if mibBuilder.loadTexts: mallocScopeNameTable.setDescription('The (conceptual) table containing information on multicast\n            scope names.  Entries in this table may be dynamically\n            discovered via some other protocol, such as MZAP, or may be\n            statically configured, such as in an isolated network\n            environment.')
mallocScopeNameEntry = MibTableRow((1, 3, 6, 1, 2, 1, 101, 1, 1, 3, 1), ).setIndexNames((0, "MALLOC-MIB", "mallocScopeAddressType"), (0, "MALLOC-MIB", "mallocScopeFirstAddress"), (1, "MALLOC-MIB", "mallocScopeNameLangName"))
if mibBuilder.loadTexts: mallocScopeNameEntry.setDescription('An entry (conceptual row) containing the information on a\n            particular multicast scope name.')
mallocScopeNameLangName = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 3, 1, 1), LanguageTag().subtype(subtypeSpec=ValueSizeConstraint(1,94)))
if mibBuilder.loadTexts: mallocScopeNameLangName.setDescription('The RFC 3066 language tag for the language of the scope\n            name.')
mallocScopeNameScopeName = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 3, 1, 2), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeNameScopeName.setDescription('The textual name associated with the multicast scope.  The\n            value of this object should be suitable for displaying to\n            end-users, such as when allocating a multicast address in\n            this scope.  If the scope is an IPv4 scope, and no name is\n            specified, the default value of this object should be the\n            string 239.x.x.x/y with x and y replaced appropriately to\n            describe the address and mask length associated with the\n            scope.  If the scope is an IPv6 scope, and no name is\n            specified, the default value of this object should\n            generically describe the scope level (e.g., site).')
mallocScopeNameDefault = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 3, 1, 3), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeNameDefault.setDescription('If true, indicates a preference that the name in the\n            associated language should be used by applications if no\n            name is available in a desired language.')
mallocScopeNameStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 3, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeNameStatus.setDescription("The status of this row, by which new entries may be\n            created, or old entries deleted from this table.  If write\n            access is supported, the other writable objects in this\n            table may be modified even while the status is `active'.")
mallocScopeNameStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 3, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocScopeNameStorage.setDescription("The storage type for this conceptual row.  Conceptual rows\n            having the value 'permanent' need not allow write-access to\n            any columnar objects in the row.")
mallocAllocRangeTable = MibTable((1, 3, 6, 1, 2, 1, 101, 1, 1, 4), )
if mibBuilder.loadTexts: mallocAllocRangeTable.setDescription("The (conceptual) table containing information on subranges\n            of addresses from which the device may allocate addresses,\n            if it is a MAAS.  If the device is a Prefix Coordinator, any\n            ranges which the device is advertising to MAAS's will be in\n            this table.  Note that the device may be both a MAAS and a\n            Prefix Coordinator.\n\n            Address ranges for different rows must be disjoint, and must\n            be contained with the address range of the corresponding row\n            of the mallocScopeTable.\n\n            Deleting an allocation range has the side effect of deleting\n            any entries within that range from the mallocAddressTable.")
mallocAllocRangeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1), ).setIndexNames((0, "MALLOC-MIB", "mallocScopeAddressType"), (0, "MALLOC-MIB", "mallocScopeFirstAddress"), (0, "MALLOC-MIB", "mallocAllocRangeFirstAddress"))
if mibBuilder.loadTexts: mallocAllocRangeEntry.setDescription('An entry (conceptual row) containing the information on a\n            particular allocation range.')
mallocAllocRangeFirstAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 1), InetAddress().subtype(subtypeSpec=ValueSizeConstraint(0,20)))
if mibBuilder.loadTexts: mallocAllocRangeFirstAddress.setDescription('The first address in the allocation range.  The type of\n            this address is determined by the value of the\n            mallocScopeAddressType object.')
mallocAllocRangeLastAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 2), InetAddress().subtype(subtypeSpec=ValueSizeConstraint(0,20))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeLastAddress.setDescription('The last address in the allocation range.  The type of this\n            address is determined by the value of the\n            mallocScopeAddressType object.')
mallocAllocRangeStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeStatus.setDescription("The status of this row, by which new entries may be\n            created, or old entries deleted from this table.  If write\n            access is supported, the other writable objects in this\n            table may be modified even while the status is `active'.")
mallocAllocRangeSource = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 4), IANAmallocRangeSource()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeSource.setDescription('The means by which this entry was learned.')
mallocAllocRangeLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 5), Unsigned32()).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeLifetime.setDescription('The number of seconds remaining in the lifetime of the\n            (sub)range out of which addresses are being allocated.  A\n            value of 0 indicates that the range is not subject to\n            aging.')
mallocAllocRangeMaxLeaseAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 6), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeMaxLeaseAddrs.setDescription('The maximum number of addresses which the server is willing\n            to grant for each future request in this range.  A value of\n            0 means that no specific limit is enforced, as long as the\n            server has valid addresses to allocate.')
mallocAllocRangeMaxLeaseTime = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 7), Unsigned32()).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeMaxLeaseTime.setDescription('The maximum lifetime which the server will grant for future\n            requests in this range.  A value of 0 means that no\n            additional limit is enforced beyond that of\n            mallocAllocRangeLifetime.')
mallocAllocRangeNumAllocatedAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeNumAllocatedAddrs.setDescription('The number of addresses in the range which have been\n            allocated.  This value can be used to determine the current\n            address space utilization within the scoped range.  This\n\n\n\n            should match the total number of addresses for this scope\n            covered by entries in the mallocAddressTable.')
mallocAllocRangeNumOfferedAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 9), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeNumOfferedAddrs.setDescription('The number of addresses in the range which have been\n            offered.  This number should match the sum of\n            mallocRequestNumAddrs for all entries in the\n            mallocRequestTable in the offered state.  Together with\n            mallocAllocRangeNumAllocatedAddrs and\n            mallocAllocRangeNumTryingAddrs, this can be used to\n            determine the address space utilization within the scoped\n            range in the immediate future.')
mallocAllocRangeNumWaitingAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 10), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeNumWaitingAddrs.setDescription('The number of addresses in the range which have been\n            requested, but whose state is waiting, while the server\n            attempts to acquire more address space.')
mallocAllocRangeNumTryingAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 11), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeNumTryingAddrs.setDescription('The number of addresses in the scope covered by entries in\n            the mallocRequestTable in the trying state.')
mallocAllocRangeAdvertisable = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 12), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeAdvertisable.setDescription('The value of this object is true if the range is eligible\n            to be advertised to other MAASs.  When the row is first\n            created, the default value of this object is true if the\n            scope is divisible, and is false otherwise.')
mallocAllocRangeTotalAllocatedAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeTotalAllocatedAddrs.setDescription('The approximate number of addresses in the range which have\n            been allocated by any MAAS, as determined by a Prefix\n            Coordinator.  This object need only be present if\n            mallocAllocRangeAdvertisable is true.  If the number is\n            unknown, a value of 0 may be reported.')
mallocAllocRangeTotalRequestedAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 14), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAllocRangeTotalRequestedAddrs.setDescription('The approximate number of addresses in the range for which\n            there is potential demand among MAASs, as determined by a\n            Prefix Coordinator.  This object need only be present if\n            mallocAllocRangeAdvertisable is true.  If the number is\n            unknown, a value of 0 may be reported.')
mallocAllocRangeStorage = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 4, 1, 15), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mallocAllocRangeStorage.setDescription("The storage type for this conceptual row.  Conceptual rows\n            having the value 'permanent' need not allow write-access to\n            any columnar objects in the row.")
mallocRequestTable = MibTable((1, 3, 6, 1, 2, 1, 101, 1, 1, 5), )
if mibBuilder.loadTexts: mallocRequestTable.setDescription('The (conceptual) table containing information on allocation\n            requests, whether allocated or in progress.  This table may\n            also be used to determine which clients are responsible for\n            high address space utilization within a given scope.\n\n\n\n            Entries in this table reflect requests dynamically received\n            by an address allocation protocol.')
mallocRequestEntry = MibTableRow((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1), ).setIndexNames((0, "MALLOC-MIB", "mallocRequestId"))
if mibBuilder.loadTexts: mallocRequestEntry.setDescription('An entry (conceptual row) containing the information on a\n            particular allocation request.')
mallocRequestId = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: mallocRequestId.setDescription('An arbitrary value identifying this row.')
mallocRequestScopeAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestScopeAddressType.setDescription('The type of the first address of the scope to which the\n            request applies.  Legal values correspond to the subset of\n            address families for which multicast address allocation is\n            supported.')
mallocRequestScopeFirstAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestScopeFirstAddress.setDescription('The first address of the scope to which the request\n            applies.  This must match mallocScopeFirstAddress for some\n            row in the mallocScopeTable.  The type of this address is\n            determined by the value of the mallocRequestScopeAddressType\n            object.')
mallocRequestStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 4), Unsigned32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestStartTime.setDescription('The number of seconds remaining before the start time of\n            the request.  A value of 0 means that the allocation is\n            currently in effect.')
mallocRequestEndTime = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 5), Unsigned32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestEndTime.setDescription('The number of seconds remaining before the end time of the\n            request.')
mallocRequestNumAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 6), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestNumAddrs.setDescription('The number of addresses requested.  If the addresses have\n            been allocated, this number should match the total number of\n            addresses for this request covered by entries in the\n            mallocAddressTable.')
mallocRequestState = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("allocated", 1), ("offered", 2), ("waiting", 3), ("trying", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestState.setDescription('The state of the request.  A value of allocated(1)\n            indicates that one or more entries for this request are\n            present in the mallocAddressTable.  A value of offered(2)\n            indicates that addresses have been offered to the client\n            (e.g. via a MADCAP OFFER message), but the allocation has\n            not been committed.  A value of waiting(3) indicates that\n            the allocation is blocked while the server attempts to\n            acquire more space from which it can allocate addresses.  A\n            value of trying(4) means that no addresses have been offered\n            to the client, but that an attempt to allocate is in\n            progress.')
mallocRequestClientAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 8), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestClientAddressType.setDescription('The type of the address of the client that (last) requested\n            this allocation.')
mallocRequestClientAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 9), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestClientAddress.setDescription('The address of the client that (last) requested this\n            allocation.  The type of this address is determined by the\n            value of the mallocRequestClientAddressType object.')
mallocRequestServerAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 10), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestServerAddressType.setDescription('The type of the address of the server to which the request\n            was (last) sent.')
mallocRequestServerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 11), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestServerAddress.setDescription('The address of the server to which the request was (last)\n            sent.  The type of this address is determined by the value\n            of the mallocRequestServerAddressType object.')
mallocRequestLeaseIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 5, 1, 12), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocRequestLeaseIdentifier.setDescription('The Lease Identifier of this request.  If the allocation\n            mechanism in use does not use Lease Identifiers, then the\n            value is a 0-length string.')
mallocAddressTable = MibTable((1, 3, 6, 1, 2, 1, 101, 1, 1, 6), )
if mibBuilder.loadTexts: mallocAddressTable.setDescription('The (conceptual) table containing information on blocks of\n            allocated addresses.  This table may be used to map a given\n            multicast group address to the associated request.')
mallocAddressEntry = MibTableRow((1, 3, 6, 1, 2, 1, 101, 1, 1, 6, 1), ).setIndexNames((0, "MALLOC-MIB", "mallocAddressAddressType"), (0, "MALLOC-MIB", "mallocAddressFirstAddress"))
if mibBuilder.loadTexts: mallocAddressEntry.setDescription('An entry (conceptual row) containing the information on a\n            particular block of allocated addresses.  The block of\n            addresses covered by each entry in this table must fall\n            within a range corresponding to an entry in the\n            mallocAllocRangeTable.')
mallocAddressAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 6, 1, 1), InetAddressType())
if mibBuilder.loadTexts: mallocAddressAddressType.setDescription('The type of the first address in the allocated block.\n            Legal values correspond to the subset of address families\n            for which multicast address allocation is supported.')
mallocAddressFirstAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 6, 1, 2), InetAddress().subtype(subtypeSpec=ValueSizeConstraint(0,20)))
if mibBuilder.loadTexts: mallocAddressFirstAddress.setDescription('The first address in the allocated block.  The type of this\n            address is determined by the value of the\n            mallocAddressAddressType object.')
mallocAddressNumAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 6, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAddressNumAddrs.setDescription('The number of addresses in the allocated block.')
mallocAddressRequestId = MibTableColumn((1, 3, 6, 1, 2, 1, 101, 1, 1, 6, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mallocAddressRequestId.setDescription('The index of the request which caused this block of\n            addresses to be allocated.  This value must match the value\n            of mallocRequestId for some entry in the\n            mallocRequestTable.')
madcapConfig = ObjectIdentity((1, 3, 6, 1, 2, 1, 101, 1, 2, 1))
if mibBuilder.loadTexts: madcapConfig.setDescription('Group of objects that count various MADCAP events.')
madcapConfigExtraAllocationTime = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 1, 1), Unsigned32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: madcapConfigExtraAllocationTime.setDescription('The amount of extra time on either side of a lease which\n            the MADCAP server allocates to allow for clock skew among\n            clients.')
madcapConfigNoResponseDelay = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 1, 2), Unsigned32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: madcapConfigNoResponseDelay.setDescription('The amount of time the MADCAP client allows for receiving a\n            response from a MADCAP server.')
madcapConfigOfferHold = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 1, 3), Unsigned32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: madcapConfigOfferHold.setDescription('The amount of time the MADCAP server will reserve an\n            address for after sending an OFFER message in anticipation\n            of receiving a REQUEST message.')
madcapConfigResponseCacheInterval = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,300))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: madcapConfigResponseCacheInterval.setDescription('The amount of time the MADCAP server uses to detect\n            duplicate messages.')
madcapConfigClockSkewAllowance = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 1, 5), Unsigned32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: madcapConfigClockSkewAllowance.setDescription('The clock skew threshold used by the MADCAP server to\n            generate Excessive Clock Skew errors.')
madcapCounters = ObjectIdentity((1, 3, 6, 1, 2, 1, 101, 1, 2, 2))
if mibBuilder.loadTexts: madcapCounters.setDescription('A group of objects that count various MADCAP events.')
madcapTotalErrors = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapTotalErrors.setDescription('The total number of transactions for which the MADCAP\n            server has detected an error of any type, regardless of\n            whether the server ignored the request or generated a NAK.')
madcapRequestsDenied = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapRequestsDenied.setDescription('The number of valid requests for which the MADCAP server\n            could not complete an allocation, regardless of whether NAKs\n            were sent.  This corresponds to the Valid Request Could Not\n            Be Completed error code in MADCAP.')
madcapInvalidRequests = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapInvalidRequests.setDescription('The number of invalid requests received by the MADCAP\n            server, regardless of whether NAKs were sent.  This\n            corresponds to the Invalid Request error code in MADCAP.')
madcapExcessiveClockSkews = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapExcessiveClockSkews.setDescription('The number of requests received by the MADCAP server with\n            an excessive clock skew, regardless of whether NAKs were\n            sent.  This corresponds to the Excessive Clock Skew error\n            code in MADCAP.')
madcapBadLeaseIds = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapBadLeaseIds.setDescription('The number of requests received by the MADCAP server with\n            an unrecognized Lease Identifier, regardless of whether NAKs\n            were sent.  This corresponds to the Lease Identifier Not\n            Recognized error code in MADCAP.')
madcapDiscovers = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapDiscovers.setDescription('The number of DISCOVER messages received by the MADCAP\n            server.')
madcapInforms = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapInforms.setDescription('The number of INFORM messages received by the MADCAP\n            server.')
madcapRequests = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapRequests.setDescription('The number of REQUEST messages received by the MADCAP\n            server.')
madcapRenews = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapRenews.setDescription('The number of RENEW messages received by the MADCAP\n            server.')
madcapReleases = MibScalar((1, 3, 6, 1, 2, 1, 101, 1, 2, 2, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: madcapReleases.setDescription('The number of RELEASE messages received by the MADCAP\n            server.')
mallocConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 101, 2))
mallocCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 101, 2, 1))
mallocGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 101, 2, 2))
mallocServerReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 101, 2, 1, 1)).setObjects(*(("MALLOC-MIB", "mallocBasicGroup"), ("MALLOC-MIB", "mallocServerGroup"),))
if mibBuilder.loadTexts: mallocServerReadOnlyCompliance.setDescription('The compliance statement for multicast address allocation\n            servers implementing the MALLOC MIB without support for\n            read-create (i.e., in read-only mode).  Such a server can\n            then be monitored but can not be configured with this MIB.')
mallocClientReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 101, 2, 1, 2)).setObjects(*(("MALLOC-MIB", "mallocBasicGroup"), ("MALLOC-MIB", "mallocClientGroup"), ("MALLOC-MIB", "mallocClientScopeGroup"), ("MALLOC-MIB", "madcapClientGroup"),))
if mibBuilder.loadTexts: mallocClientReadOnlyCompliance.setDescription('The compliance statement for clients implementing the\n            MALLOC MIB without support for read-create (i.e., in read-\n            only mode).  Such clients can then be monitored but can not\n            be configured with this MIB.')
mallocPrefixCoordinatorReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 101, 2, 1, 3)).setObjects(*(("MALLOC-MIB", "mallocBasicGroup"), ("MALLOC-MIB", "mallocPrefixCoordinatorGroup"),))
if mibBuilder.loadTexts: mallocPrefixCoordinatorReadOnlyCompliance.setDescription('The compliance statement for prefix coordinators\n            implementing the MALLOC MIB without support for read-create\n            (i.e., in read-only mode).  Such devices can then be\n            monitored but can not be configured with this MIB.')
mallocServerFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 101, 2, 1, 4)).setObjects(*(("MALLOC-MIB", "mallocBasicGroup"), ("MALLOC-MIB", "mallocServerGroup"), ("MALLOC-MIB", "madcapServerGroup"),))
if mibBuilder.loadTexts: mallocServerFullCompliance.setDescription('The compliance statement for multicast address allocation\n            servers implementing the MALLOC MIB with support for read-\n            create.  Such servers can then be both monitored and\n            configured with this MIB.')
mallocClientFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 101, 2, 1, 5)).setObjects(*(("MALLOC-MIB", "mallocBasicGroup"), ("MALLOC-MIB", "mallocClientGroup"), ("MALLOC-MIB", "mallocClientScopeGroup"), ("MALLOC-MIB", "madcapClientGroup"),))
if mibBuilder.loadTexts: mallocClientFullCompliance.setDescription('The compliance statement for hosts implementing the MALLOC\n            MIB with support for read-create.  Such clients can then be\n            both monitored and configured with this MIB.')
mallocPrefixCoordinatorFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 101, 2, 1, 6)).setObjects(*(("MALLOC-MIB", "mallocBasicGroup"), ("MALLOC-MIB", "mallocPrefixCoordinatorGroup"),))
if mibBuilder.loadTexts: mallocPrefixCoordinatorFullCompliance.setDescription('The compliance statement for prefix coordinators\n            implementing the MALLOC MIB with support for read-create.\n            Such devices can then be both monitored and configured with\n            this MIB.')
mallocBasicGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 1)).setObjects(*(("MALLOC-MIB", "mallocCapabilities"), ("MALLOC-MIB", "mallocRequestScopeAddressType"), ("MALLOC-MIB", "mallocRequestScopeFirstAddress"), ("MALLOC-MIB", "mallocRequestStartTime"), ("MALLOC-MIB", "mallocRequestEndTime"), ("MALLOC-MIB", "mallocRequestNumAddrs"), ("MALLOC-MIB", "mallocRequestState"), ("MALLOC-MIB", "mallocAddressNumAddrs"), ("MALLOC-MIB", "mallocAddressRequestId"),))
if mibBuilder.loadTexts: mallocBasicGroup.setDescription('The basic collection of objects providing management of IP\n            multicast address allocation.')
mallocServerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 2)).setObjects(*(("MALLOC-MIB", "mallocScopeLastAddress"), ("MALLOC-MIB", "mallocScopeHopLimit"), ("MALLOC-MIB", "mallocScopeSSM"), ("MALLOC-MIB", "mallocScopeStatus"), ("MALLOC-MIB", "mallocScopeStorage"), ("MALLOC-MIB", "mallocAllocRangeLastAddress"), ("MALLOC-MIB", "mallocAllocRangeLifetime"), ("MALLOC-MIB", "mallocAllocRangeNumAllocatedAddrs"), ("MALLOC-MIB", "mallocAllocRangeNumOfferedAddrs"), ("MALLOC-MIB", "mallocAllocRangeNumWaitingAddrs"), ("MALLOC-MIB", "mallocAllocRangeNumTryingAddrs"), ("MALLOC-MIB", "mallocAllocRangeMaxLeaseAddrs"), ("MALLOC-MIB", "mallocAllocRangeMaxLeaseTime"), ("MALLOC-MIB", "mallocAllocRangeSource"), ("MALLOC-MIB", "mallocAllocRangeStatus"), ("MALLOC-MIB", "mallocAllocRangeStorage"), ("MALLOC-MIB", "mallocScopeDivisible"), ("MALLOC-MIB", "mallocScopeSource"), ("MALLOC-MIB", "mallocScopeNameScopeName"), ("MALLOC-MIB", "mallocScopeNameDefault"), ("MALLOC-MIB", "mallocScopeNameStatus"), ("MALLOC-MIB", "mallocScopeNameStorage"), ("MALLOC-MIB", "mallocRequestClientAddressType"), ("MALLOC-MIB", "mallocRequestClientAddress"),))
if mibBuilder.loadTexts: mallocServerGroup.setDescription('A collection of objects providing management of multicast\n            address allocation in servers.')
mallocClientGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 3)).setObjects(*(("MALLOC-MIB", "mallocRequestServerAddressType"), ("MALLOC-MIB", "mallocRequestServerAddress"),))
if mibBuilder.loadTexts: mallocClientGroup.setDescription('A collection of objects providing management of multicast\n            address allocation in clients.')
madcapServerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 4)).setObjects(*(("MALLOC-MIB", "madcapConfigClockSkewAllowance"), ("MALLOC-MIB", "madcapConfigExtraAllocationTime"), ("MALLOC-MIB", "madcapConfigOfferHold"), ("MALLOC-MIB", "madcapConfigResponseCacheInterval"), ("MALLOC-MIB", "madcapTotalErrors"), ("MALLOC-MIB", "madcapRequestsDenied"), ("MALLOC-MIB", "madcapInvalidRequests"), ("MALLOC-MIB", "madcapBadLeaseIds"), ("MALLOC-MIB", "madcapExcessiveClockSkews"), ("MALLOC-MIB", "madcapDiscovers"), ("MALLOC-MIB", "madcapInforms"), ("MALLOC-MIB", "madcapRequests"), ("MALLOC-MIB", "madcapRenews"), ("MALLOC-MIB", "madcapReleases"),))
if mibBuilder.loadTexts: madcapServerGroup.setDescription('A collection of objects providing management of MADCAP\n            servers.')
madcapClientGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 5)).setObjects(*(("MALLOC-MIB", "mallocRequestLeaseIdentifier"), ("MALLOC-MIB", "madcapConfigNoResponseDelay"),))
if mibBuilder.loadTexts: madcapClientGroup.setDescription('A collection of objects providing management of MADCAP\n            clients.')
mallocClientScopeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 6)).setObjects(*(("MALLOC-MIB", "mallocScopeLastAddress"), ("MALLOC-MIB", "mallocScopeHopLimit"), ("MALLOC-MIB", "mallocScopeStatus"), ("MALLOC-MIB", "mallocScopeStorage"), ("MALLOC-MIB", "mallocScopeSource"), ("MALLOC-MIB", "mallocScopeServerAddressType"), ("MALLOC-MIB", "mallocScopeServerAddress"), ("MALLOC-MIB", "mallocScopeSSM"), ("MALLOC-MIB", "mallocScopeNameScopeName"), ("MALLOC-MIB", "mallocScopeNameDefault"), ("MALLOC-MIB", "mallocScopeNameStatus"), ("MALLOC-MIB", "mallocScopeNameStorage"),))
if mibBuilder.loadTexts: mallocClientScopeGroup.setDescription('A collection of objects providing management of multicast\n            scope information in clients.')
mallocPrefixCoordinatorGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 101, 2, 2, 7)).setObjects(*(("MALLOC-MIB", "mallocAllocRangeLastAddress"), ("MALLOC-MIB", "mallocAllocRangeLifetime"), ("MALLOC-MIB", "mallocAllocRangeStatus"), ("MALLOC-MIB", "mallocAllocRangeStorage"), ("MALLOC-MIB", "mallocAllocRangeSource"), ("MALLOC-MIB", "mallocAllocRangeTotalAllocatedAddrs"), ("MALLOC-MIB", "mallocAllocRangeTotalRequestedAddrs"), ("MALLOC-MIB", "mallocAllocRangeAdvertisable"), ("MALLOC-MIB", "mallocScopeLastAddress"), ("MALLOC-MIB", "mallocScopeDivisible"), ("MALLOC-MIB", "mallocScopeSource"),))
if mibBuilder.loadTexts: mallocPrefixCoordinatorGroup.setDescription('A collection of objects for managing Prefix Coordinators.')
mibBuilder.exportSymbols("MALLOC-MIB", mallocRequestScopeFirstAddress=mallocRequestScopeFirstAddress, mallocRequestLeaseIdentifier=mallocRequestLeaseIdentifier, madcapInvalidRequests=madcapInvalidRequests, mallocAllocRangeNumWaitingAddrs=mallocAllocRangeNumWaitingAddrs, mallocAllocRangeStatus=mallocAllocRangeStatus, mallocAddressFirstAddress=mallocAddressFirstAddress, mallocClientReadOnlyCompliance=mallocClientReadOnlyCompliance, mallocAddressAddressType=mallocAddressAddressType, mallocCompliances=mallocCompliances, mallocScopeHopLimit=mallocScopeHopLimit, madcapRequestsDenied=madcapRequestsDenied, mallocRequestClientAddress=mallocRequestClientAddress, PYSNMP_MODULE_ID=mallocMIB, mallocRequestState=mallocRequestState, mallocAllocRangeLastAddress=mallocAllocRangeLastAddress, mallocScopeLastAddress=mallocScopeLastAddress, mallocAllocRangeEntry=mallocAllocRangeEntry, mallocAllocRangeStorage=mallocAllocRangeStorage, mallocAllocRangeTable=mallocAllocRangeTable, madcapClientGroup=madcapClientGroup, mallocServerFullCompliance=mallocServerFullCompliance, mallocClientGroup=mallocClientGroup, mallocScopeSSM=mallocScopeSSM, mallocAddressTable=mallocAddressTable, mallocScopeNameScopeName=mallocScopeNameScopeName, mallocScopeTable=mallocScopeTable, mallocRequestScopeAddressType=mallocRequestScopeAddressType, mallocScopeFirstAddress=mallocScopeFirstAddress, mallocAllocRangeNumAllocatedAddrs=mallocAllocRangeNumAllocatedAddrs, mallocRequestClientAddressType=mallocRequestClientAddressType, madcapCounters=madcapCounters, madcapExcessiveClockSkews=madcapExcessiveClockSkews, mallocCapabilities=mallocCapabilities, mallocClientScopeGroup=mallocClientScopeGroup, mallocAllocRangeNumOfferedAddrs=mallocAllocRangeNumOfferedAddrs, mallocRequestNumAddrs=mallocRequestNumAddrs, madcapTotalErrors=madcapTotalErrors, mallocAllocRangeTotalAllocatedAddrs=mallocAllocRangeTotalAllocatedAddrs, mallocRequestServerAddress=mallocRequestServerAddress, mallocServerGroup=mallocServerGroup, mallocPrefixCoordinatorFullCompliance=mallocPrefixCoordinatorFullCompliance, malloc=malloc, mallocAddressRequestId=mallocAddressRequestId, mallocBasicGroup=mallocBasicGroup, mallocAllocRangeNumTryingAddrs=mallocAllocRangeNumTryingAddrs, mallocScopeNameEntry=mallocScopeNameEntry, mallocAllocRangeAdvertisable=mallocAllocRangeAdvertisable, mallocConformance=mallocConformance, mallocScopeNameLangName=mallocScopeNameLangName, mallocPrefixCoordinatorReadOnlyCompliance=mallocPrefixCoordinatorReadOnlyCompliance, mallocPrefixCoordinatorGroup=mallocPrefixCoordinatorGroup, madcapInforms=madcapInforms, madcapConfigResponseCacheInterval=madcapConfigResponseCacheInterval, mallocAllocRangeMaxLeaseAddrs=mallocAllocRangeMaxLeaseAddrs, mallocRequestStartTime=mallocRequestStartTime, mallocRequestEntry=mallocRequestEntry, madcapConfigNoResponseDelay=madcapConfigNoResponseDelay, mallocClientFullCompliance=mallocClientFullCompliance, mallocAllocRangeTotalRequestedAddrs=mallocAllocRangeTotalRequestedAddrs, madcapServerGroup=madcapServerGroup, madcapConfigExtraAllocationTime=madcapConfigExtraAllocationTime, madcapConfigOfferHold=madcapConfigOfferHold, mallocAddressEntry=mallocAddressEntry, madcapRequests=madcapRequests, madcapConfig=madcapConfig, mallocScopeDivisible=mallocScopeDivisible, mallocScopeServerAddress=mallocScopeServerAddress, mallocScopeStorage=mallocScopeStorage, madcapReleases=madcapReleases, mallocAllocRangeFirstAddress=mallocAllocRangeFirstAddress, mallocScopeSource=mallocScopeSource, mallocRequestTable=mallocRequestTable, mallocGroups=mallocGroups, mallocScopeAddressType=mallocScopeAddressType, mallocRequestEndTime=mallocRequestEndTime, madcapConfigClockSkewAllowance=madcapConfigClockSkewAllowance, mallocScopeStatus=mallocScopeStatus, mallocAddressNumAddrs=mallocAddressNumAddrs, mallocScopeNameDefault=mallocScopeNameDefault, mallocScopeServerAddressType=mallocScopeServerAddressType, mallocRequestServerAddressType=mallocRequestServerAddressType, mallocAllocRangeSource=mallocAllocRangeSource, madcapBadLeaseIds=madcapBadLeaseIds, mallocScopeEntry=mallocScopeEntry, madcapDiscovers=madcapDiscovers, mallocAllocRangeLifetime=mallocAllocRangeLifetime, mallocMIBObjects=mallocMIBObjects, madcap=madcap, mallocScopeNameStorage=mallocScopeNameStorage, mallocScopeNameTable=mallocScopeNameTable, mallocAllocRangeMaxLeaseTime=mallocAllocRangeMaxLeaseTime, mallocRequestId=mallocRequestId, madcapRenews=madcapRenews, mallocScopeNameStatus=mallocScopeNameStatus, mallocServerReadOnlyCompliance=mallocServerReadOnlyCompliance, mallocMIB=mallocMIB)
